package controller

import (
	"fmt"
	"github.com/gin-gonic/gin"
	"hongze/hongze_sync_trial/controller/resp"
	"hongze/hongze_sync_trial/models/request"
	"hongze/hongze_sync_trial/models/response"
	"hongze/hongze_sync_trial/models/table/edb_info"
	"hongze/hongze_sync_trial/utils"
)

// CommonController 接口
type CommonController struct {
}

// GetEdbInfoByEdbCode 根据指标编码获取指标信息
func (s *CommonController) GetEdbInfoByEdbCode(c *gin.Context) {
	var req request.GetEdbInfoByEdbCodeReq
	if err := c.ShouldBindQuery(&req); err != nil {
		fmt.Println("bind err:", err)
		resp.Fail("参数有误", c)
		return
	}
	if req.EdbCode == `` {
		resp.Fail("指标编码未提交", c)
		return
	}
	if req.Source <= 0 {
		resp.Fail("指标来源未提交", c)
		return
	}

	edbInfo, err := edb_info.GetEdbInfoByEdbCode(req.EdbCode, req.Source)
	if err != nil && err != utils.ErrNoRow {
		resp.FailMsg("获取失败", "获取失败,ERR："+err.Error(), c)
		return
	}

	respData := response.EdbInfoByEdbCodeResp{
		EdbCode:      req.EdbCode,
		Source:       req.Source,
		ServerURL:    edbInfo.ServerURL,
		TerminalCode: edbInfo.TerminalCode,
	}

	resp.OkData("获取成功", respData, c)

	return
}
